@@ -1,46 +1,34 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HD_ST_VBO_MEMORY_MANAGER_H
 #define PXR_IMAGING_HD_ST_VBO_MEMORY_MANAGER_H
 
 #include "pxr/pxr.h"
+
+#include "pxr/base/tf/envSetting.h"
+
 #include "pxr/imaging/hdSt/api.h"
 #include "pxr/imaging/hdSt/strategyBase.h"
+#include "pxr/imaging/hdSt/bufferArrayRange.h"
+
+#include "pxr/imaging/hgi/enums.h"
 
 #include "pxr/imaging/hd/bufferArray.h"
-#include "pxr/imaging/hdSt/bufferArrayRange.h"
 #include "pxr/imaging/hd/bufferSpec.h"
 #include "pxr/imaging/hd/bufferSource.h"
 
-#include "pxr/base/tf/mallocTag.h"
-#include "pxr/base/tf/token.h"
-
 #include <list>
 #include <memory>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
+HDST_API
+extern TfEnvSetting<int> HD_MAX_VBO_SIZE;
+
 class HdStResourceRegistry;
 
 /// \class HdStVBOMemoryManager
@@ -317,6 +305,7 @@ protected:
         bool _needsCompaction;
         int _totalCapacity;
         size_t _maxBytesPerElement;
+        HgiBufferUsage _bufferUsage;
 
         HdStBufferResourceNamedList _resourceList;
 
